--[[
## Title: FarmIt
## Notes: Custom loot tracker. By CHiLLZ [v1.5]
## SavedVariablesPerCharacter: FI_Config
##
## Author: CHiLLZ <chillz@xmission.com>
## License: Copyright 2006-2008, Chillz Media. All rights reserved.

To Do:
	(Performance) 
		Keep a timestamp each time FI_Update() is triggered, and 
		have a threshold check to keep it from running 2-3 times in a row.
		ie- Minimum of 1 sec between scans.

	(Features)
		Dynamic slot/icon scaling.

		Set font size/color of item text.

		Farming templates - ability to save a set of item ID's as a farming "template".

		Set a time marker to track farming "sessions"
		This would need logging functionality if it is going to provide historical info once session is over.

		Basic money tracking during a "session".
		
		Multiple bars.

		Right-click interacts with actual inventory item. ie- For combining motes into primals.
		
		Calculate estimated drop rates for tracked items.

		Respawn timer.

		Work with auctioneer to track $$ value of items farmed?
]]--

--------------------------------------------------------------------------------
--  SETTINGS
--------------------------------------------------------------------------------
local FI_Debug = false;
local FI_Title = "FarmIt"
local FI_Version = 1.5;
local FI_Bars = 1;
local FI_MaxSlots = 12;
local FI_Pad = 6;
local FI_Selected = false;

local FI_Defaults = {
	-- general settings
	["Version"] = FI_Version,
	["Display"] = {
		["FI"] = true,
		["FI_B1"] = true,
	},
	["Notify"] = true,
	-- bar settings
	["Bars"] = {
		["FI_B1"] = "FarmIt",
	},
	["Slots"] = {
		["FI_B1"] = 2,
	},
	["Align"] = {
		["FI_B1"] = "RIGHT",
	},
	["Text"] = {
		["FI_B1"] = true,
	},
	["Orientation"] = {
		["FI_B1"] = "VERTICAL",
	},
	-- item slot settings
	["Items"] = {
		["FI_B1_S1"] = false,
		["FI_B1_S2"] = false,
	},
	["IncludeBank"] = {
		["FI_B1_S1"] = false,
		["FI_B1_S2"] = false,
	},
	["Quantity"] = {
		["FI_B1_S1"] = 0,
		["FI_B1_S2"] = 0,
	},
	["Objective"] = {
		["FI_B1_S1"] = 0,
		["FI_B1_S2"] = 0,
	},
	["Notified"] = {
		["FI_B1_S1"] = false,
		["FI_B1_S2"] = false,
	},
}

--------------------------------------------------------------------------------
--  LOADING
--------------------------------------------------------------------------------
function FI_OnLoad()
	FI:RegisterForDrag("LeftButton");
	FI:RegisterEvent("ADDON_LOADED");
	FI:RegisterEvent("UNIT_INVENTORY_CHANGED");
	FI:RegisterEvent("BAG_UPDATE");
	
	SlashCmdList["farmit"] = FI_Command;
	SLASH_farmit1 = "/farmit";
end

function FI_OnShow()
	
end

function FI_OnEvent()
	if ((event == "ADDON_LOADED") and (arg1 == FI_Title)) then
		FI_Loader();
	end
	
	if (event == "UNIT_INVENTORY_CHANGED" or "BAG_UPDATE") then
		FI_Update();
	end
end

function FI_Loader()
	FI_Loading = true;

	if (not FI_Config) then
		-- first run
		FI_Config = FI_Defaults;
		DEFAULT_CHAT_FRAME:AddMessage( "FarmIt v"..FI_Version.." initialized!  By CHiLLZ" );
	elseif (not FI_Config["Version"]) then
		-- old version check
		FI_Config = FI_Defaults;
		DEFAULT_CHAT_FRAME:AddMessage( "FarmIt v"..FI_Version.." upgraded!  By CHiLLZ" );
	elseif (FI_Version > FI_Config["Version"]) then
		-- new version
		FI_Config = FI_Defaults;
		DEFAULT_CHAT_FRAME:AddMessage( "FarmIt v"..FI_Version.." upgraded.  By CHiLLZ" );
	else
		-- normal load
		DEFAULT_CHAT_FRAME:AddMessage( "FarmIt v"..FI_Version.." loaded.  By CHiLLZ" );
	end

	-- slash interface
	DEFAULT_CHAT_FRAME:AddMessage( "  For a list of commands, type:  /farmit" );
	
	-- do startup routine
	FI_Core();

	FI_Loading = false;
end

function FI_Core()
	-- set help window contents
	FI_HelpText();

	-- need to turn this into a loop (FI_Bars) to handle multiple bars
	bar = "FI_B1";

	-- create bar frame
	FI_CreateBar(bar, FI, FI);

	-- set bar name
	FI_B1_Anchor_Label:SetText(FI_Title);
	
	-- create slot frames
	for s=1,FI_MaxSlots do
		local slot = bar.."_S"..s;
		
		-- dynamic anchoring
		if (s > 1) then
			local prev = "_S"..s-1;
			anchor = bar..prev;
		else
			anchor = bar;
		end
		
		-- create slot frame
		FI_CreateSlot(slot, getglobal(bar), anchor);
		
		-- load tracked items
		FI_SetSlot(slot);
		
		-- apply text settings
		FI_TextAlign(slot,  FI_Config["Align"][bar]);
	end
	
	-- set visibility
	FI_TextVis(bar);
	FI_SetBar(bar);
	FI_SetVis("FI");
end

function FI_Reset()
	-- move to default location
	FI:ClearAllPoints();
	FI:SetPoint("LEFT", "UIParent", "LEFT", 0, 0);
	PlaySound("igCharacterInfoClose");
	
	-- copy default options over saved vars
	FI_Config = FI_Defaults;
	getglobal("FI_B1_Anchor_Label"):SetText(FI_Title);
	
	-- loop through slots
	local bar = "FI_B1";
	for s=1,FI_MaxSlots do
		local slot = bar.."_S"..s;
		-- reset graphics
		FI_ClearSlot(slot);
		FI_TextAlign(slot, FI_Defaults["Align"][bar]);
	end

	FI_TextVis(bar);
	FI_SetBar(bar);
	FI_MoveSlots(bar);
	FI_SetVis("FI");
	
	DEFAULT_CHAT_FRAME:AddMessage( "Farmit:  Mod reset." );
end

--------------------------------------------------------------------------------
--  HELPER FUNCTIONS
--------------------------------------------------------------------------------
function FI_Boolean( value )
	local text;
	
	if (value) then
		text = "true";
	else
		text = "false";
	end
	
	return text;
end

function FI_Toggle( value )
	if (value) then
		value = false;
	else
		value = true;
	end
	return value;
end

function FI_SetVis( element )
	local display = FI_Config["Display"][element];
	
	if (display) then
		getglobal(element):Show();
	else
		getglobal(element):Hide();
	end
end

function FI_ToggleVis( element )
	-- change setting
	FI_Config["Display"][element] = FI_Toggle(FI_Config["Display"][element]);
	
	-- apply change
	FI_SetVis( element );
end

--------------------------------------------------------------------------------
--  FRAME CREATION
--------------------------------------------------------------------------------
function FI_CreateBar( bar, parent, anchor )
	-- create bar using template frame
	local b = CreateFrame("Frame", bar, parent, "FI_TPL_BAR");
	b:SetFrameStrata("BACKGROUND");
	b:SetWidth(38);
	b:SetHeight(36);
	b:SetPoint("BOTTOM", anchor, "BOTTOM", 0,0);

	-- create slots
	for s=1,FI_MaxSlots do
		-- assemble frame name
		local slot = bar.."_S"..s;
		
		-- dynamic anchoring
		if (s > 1) then
			local prev = "_S"..s-1;
			anchor = bar..prev;
		else
			anchor = bar;
		end
		
		-- create slot frame
		FI_CreateSlot(slot, getglobal(bar), anchor);
		
		-- apply slot settings
		FI_SetSlot(slot);
		FI_TextAlign(slot, FI_Config["Align"][bar]);
	end
end

function FI_CreateSlot( slot, bar, anchor )
	-- create slot using template frame
	local s = CreateFrame("Frame", slot, bar, "FI_TPL_SLOT");
	s:SetFrameStrata("BACKGROUND");
	s:SetWidth(36);
	s:SetHeight(36);
	
	-- set slot appearance
	--local t = s:CreateTexture(nil,"BACKGROUND");
	--t:SetTexture("Interface\\PaperDoll\\UI-Backpack-EmptySlot");
	--t:SetAllPoints(s);
	--s.texture = t;
	
	-- handle bar orientation
	if (FI_Config["Orientation"]["FI_B1"] == "VERTICAL") then
		s:SetPoint("BOTTOM", anchor, "TOP", 0,FI_Pad);
	elseif (FI_Config["Orientation"]["FI_B1"] == "HORIZONTAL") then
		-- note: this part breaks if using the getglobal(bar) passed in from FI_CreateBar()
		if (FI_Config["Align"]["FI_B1"] == "RIGHT") then
			s:SetPoint("LEFT", anchor, "RIGHT", FI_Pad,0);
		else
			s:SetPoint("RIGHT", anchor, "LEFT", -FI_Pad,0);
		end
	end
end

--------------------------------------------------------------------------------
--  ITEM SLOTS
--------------------------------------------------------------------------------
function FI_Click( slot )
	if (arg1 == "RightButton") then
		------------------------------------------------------------
		-- clear slot contents
		------------------------------------------------------------
		FI_ClearSlot(slot);
		PlaySound("igMainMenuClose");

	elseif (CursorHasItem()) then
		------------------------------------------------------------
		-- get item off cursor
		------------------------------------------------------------
		local cursorType, itemID, cursorLink = GetCursorInfo();
		ClearCursor();

		-- set slot contents
		FI_Config["Items"][slot] = itemID;
		FI_ClearObjective(slot);
		FI_SetSlot(slot);

	elseif (FI_Selected) then
		------------------------------------------------------------
		-- move item
		------------------------------------------------------------
		local prevSlot = FI_Selected["Slot"];

		if (prevSlot == slot) then 
			------------------------------------------------------------
			-- cancel the selection (same slot was clicked)
			------------------------------------------------------------
			FI_Deselect();

		elseif (FI_Config["Items"][slot]) then
			------------------------------------------------------------
			-- move target slot item to previously selected slot (swap)
			------------------------------------------------------------
			FI_Config["Items"][prevSlot] = FI_Config["Items"][slot];
			FI_Config["IncludeBank"][prevSlot] = FI_Config["IncludeBank"][slot];
			FI_Config["Quantity"][prevSlot] = FI_Config["Quantity"][slot];
			FI_Config["Objective"][prevSlot] = FI_Config["Objective"][slot];

			-- set selected (previous) slot contents
			FI_SetSlot(prevSlot);

			-- clear target slot contents
			FI_ClearSlot(slot);

			-- get contents from selected var
			FI_Config["Items"][slot] = FI_Selected["ItemID"];
			FI_Config["IncludeBank"][slot] = FI_Selected["IncludeBank"];
			FI_Config["Quantity"][slot] = FI_Selected["Quantity"];
			FI_Config["Objective"][slot] = FI_Selected["Objective"];

			-- set slot contents
			FI_SetSlot(slot);

			-- clear selection
			FI_Deselect();

		else
			------------------------------------------------------------
			-- move item into empty slot
			------------------------------------------------------------
			FI_ClearSlot(slot);

			-- get contents from previously selected slot
			FI_Config["Items"][slot] = FI_Selected["ItemID"];
			FI_Config["IncludeBank"][slot] = FI_Selected["IncludeBank"];
			FI_Config["Quantity"][slot] = FI_Selected["Quantity"];
			FI_Config["Objective"][slot] = FI_Selected["Objective"];

			-- set slot contents
			FI_SetSlot(slot);

			-- clear previously selected slot
			FI_ClearSlot(prevSlot);

			-- clear selection
			FI_Deselect();
		end

	elseif (not IsShiftKeyDown() and not IsControlKeyDown()) then
		------------------------------------------------------------
		-- select slot contents
		------------------------------------------------------------
		if (FI_Config["Items"][slot]) then
			FI_Select(slot);
		end

	end
end

function FI_Select( slot )
	-- get item slot settings
	FI_Selected = {
		["Slot"] = slot,
		["ItemID"] = FI_Config["Items"][slot],
		["IncludeBank"] = FI_Config["IncludeBank"][slot],
		["Quantity"] = FI_Config["Quantity"][slot],
		["Objective"] = FI_Config["Objective"][slot],
	}
	-- show selection indicator
	getglobal(slot.."_Glow"):Show();
	PlaySound("igAbilityIconPickup");
end

function FI_Deselect()
	local slot = FI_Selected["Slot"];
	FI_Selected = false;
	-- hide selection indicator
	getglobal(slot.."_Glow"):Hide();
	PlaySound("igAbilityIconDrop");
end

function FI_SetSlot( slot )
	local itemID = FI_Config["Items"][slot];
	local includeBank = FI_Config["IncludeBank"][slot];

	if (includeBank) then
		getglobal(slot.."_Count"):SetVertexColor(1, 1, 0);
	else
		getglobal(slot.."_Count"):SetVertexColor(1, 1, 1);
	end

	if (itemID) then
		local itemName, itemLink, itemRarity, itemLevel, itemMinLevel, itemType, itemSubType, itemStackCount, itemEquipLoc, itemTexture = GetItemInfo(itemID);
		local itemCount = GetItemCount(itemID, includeBank);
		FI_Config["Quantity"][slot] = itemCount;

		getglobal(slot.."_Icon"):SetTexture(itemTexture);
		getglobal(slot.."_Count"):SetText(itemCount);
		getglobal(slot.."_Text"):SetText(itemName);
		
		-- item quantity objective
		FI_SetObjective(slot);

		if (FI_Debug) then 
			DEFAULT_CHAT_FRAME:AddMessage( "Farmit:  "..slot.." set to "..itemLink );
		end
	else
		FI_ClearSlot(slot);
	end
end

function FI_ClearSlot( slot )
	FI_Config["Items"][slot] = false;
	FI_Config["IncludeBank"][slot] = false;
	FI_Config["Quantity"][slot] = 0;
	
	FI_ClearObjective(slot);
	
	getglobal(slot.."_Icon"):SetTexture("");
	getglobal(slot.."_Count"):SetText("0");
	getglobal(slot.."_Count"):SetVertexColor(1, 1, 1);
	getglobal(slot.."_Text"):SetText("");

	--PlaySound("igMainMenuClose");
end

function FI_Update()
	local bar = "FI_B1";
	for s=1,FI_Config["Slots"][bar] do
		local slot = "FI_B1_S"..s;
		local itemID = FI_Config["Items"][slot];
		local includeBank = FI_Config["IncludeBank"][slot];
		
		if (itemID) then
			local itemCount = GetItemCount(itemID, includeBank);
			FI_Config["Quantity"][slot] = itemCount;
			getglobal(slot.."_Count"):SetText(itemCount);
		end

		FI_CheckObjective(slot);
	end
end

function FI_ToggleBank( slot )
	if (FI_Config["Items"][slot]) then
		-- change setting
		FI_Config["IncludeBank"][slot] = FI_Toggle(FI_Config["IncludeBank"][slot]);
		
		
		-- apply change
		if (FI_Config["IncludeBank"][slot]) then
			getglobal(slot.."_Count"):SetVertexColor(1, 1, 0);
		else
			getglobal(slot.."_Count"):SetVertexColor(1, 1, 1);
		end
		
		-- update item counts
		FI_Update();

		if (not FI_Loading) then
			PlaySound("TalentScreenClose");
		end
		DEFAULT_CHAT_FRAME:AddMessage( "FarmIt:  "..slot.." IncludeBank = "..FI_Boolean(FI_Config["IncludeBank"][slot])	);
	end
end

function FI_EditObjective( currentSlot )
	-- hide any other open edit boxes
	local bar = "FI_B1";
	for s=1,FI_MaxSlots do
		local slot = bar.."_S"..s;
		getglobal(slot.."_Edit"):Hide();
	end
	-- show requested edit box
	getglobal(currentSlot.."_Edit"):Show();
	-- auto select text for editing
	getglobal(currentSlot.."_Edit"):HighlightText();
end

function FI_SetObjective( slot, editbox )
	-- get user input?
	if (editbox) then
		FI_Config["Objective"][slot] = getglobal(slot.."_Edit"):GetNumber();
	end

	-- apply settings
	getglobal(slot.."_Objective"):SetText( FI_Config["Objective"][slot] );
	getglobal(slot.."_Edit"):SetText( FI_Config["Objective"][slot] );

	-- show it
	if (FI_Config["Objective"][slot] > 0) then
		FI_CheckObjective(slot);
		getglobal(slot.."_Objective"):Show();
	else
		getglobal(slot.."_Objective"):Hide();
	end

end

function FI_ClearObjective( slot )
	FI_Config["Objective"][slot] = 0;
	getglobal(slot.."_Objective"):SetText( FI_Config["Objective"][slot] );
	getglobal(slot.."_Edit"):SetText( FI_Config["Objective"][slot] );

	getglobal(slot.."_Objective"):Hide();
end

function FI_CheckObjective( slot )
	if (FI_Config["Quantity"][slot] >= FI_Config["Objective"][slot]) then
		-- set objective color
		getglobal(slot.."_Objective"):SetVertexColor(.3, 1, .3);
		
		-- only notify if there is an item and its the first time, can be disabled
		if (FI_Config["Notify"] and FI_Config["Items"][slot] and FI_Config["Objective"][slot] > 0 and not FI_Config["Notified"][slot] and not FI_Loading) then
			-- get item link
			local sName, sLink, iRarity, iLevel, iMinLevel, sType, sSubType, iStackCount = GetItemInfo(FI_Config["Items"][slot]);

			-- on-screen success notification
			local message = "Farming objective met for "..sLink.."  ("..FI_Config["Quantity"][slot].."/"..FI_Config["Objective"][slot]..")";
			local r = 0.9; local g = 0.9; local b = 0.3;
			UIErrorsFrame:AddMessage(message, r, g, b);

			-- set notification flag
			FI_Config["Notified"][slot] = true;
		end
	else
		getglobal(slot.."_Objective"):SetVertexColor(1, .2, .2);
		-- reset success notification flag
		FI_Config["Notified"][slot] = false;
	end
end

function FI_Tooltip( slot )
	local bar = "FI_B1";
	if (FI_Config["Items"][slot] and FI_Config["Orientation"][bar] == "HORIZONTAL") then
		local sName, sLink, iRarity, iLevel, iMinLevel, sType, sSubType, iStackCount = GetItemInfo(FI_Config["Items"][slot]);
		GameTooltip:SetOwner(getglobal(slot), "ANCHOR_TOPLEFT");
		GameTooltip:SetText(sName);
	end
end

--------------------------------------------------------------------------------
--  BAR FUNCTIONALITY
--------------------------------------------------------------------------------
function FI_ChangeBar( action )
	local bar = "FI_B1";
	local current = FI_Config["Slots"][bar];
	
	-- change setting
	if (action == "+") then
		if (current < FI_MaxSlots) then
			FI_Config["Slots"][bar] = current+1;
		end
	elseif (action == "-") then
		if (current > 1) then
			FI_Config["Slots"][bar] = current-1;
		end
	end
	
	-- apply the change
	PlaySound("gsTitleOptionOK");
	FI_SetBar("FI_B1");
	FI_Update();
end

function FI_SetBar( bar )
	for s=1,FI_MaxSlots do
		local slot = "_S"..s;
		local fName = bar..slot;
		getglobal(fName):Hide();
	end
	
	for s=1,FI_Config["Slots"][bar] do
		local slot = "_S"..s;
		local fName = bar..slot;
		getglobal(fName):Show();
	end
end

function FI_ToggleAlign( bar )
	-- change the setting
	if (FI_Config["Align"][bar] == "LEFT") then
		FI_Config["Align"][bar] = "RIGHT";
	else
		FI_Config["Align"][bar] = "LEFT";
	end

	-- apply the change
	for s=1,FI_MaxSlots do
		local slot = bar.."_S"..s;
		FI_TextAlign(slot,  FI_Config["Align"][bar]);
	end

	if (FI_Config["Orientation"][bar] == "HORIZONTAL") then
		FI_MoveSlots(bar);
	end
	
	DEFAULT_CHAT_FRAME:AddMessage( "FarmIt:  Align = "..FI_Config["Align"][bar] );
end

function FI_Orientation( bar )
	-- change settings
	if (FI_Config["Orientation"][bar] == "VERTICAL") then
		FI_Config["Orientation"][bar] = "HORIZONTAL";
		FI_Config["Text"][bar] = false;
	elseif (FI_Config["Orientation"][bar] == "HORIZONTAL") then
		FI_Config["Orientation"][bar] = "VERTICAL";
		FI_Config["Text"][bar] = true;
	end
	
	-- apply the change
	FI_TextVis(bar);
	FI_MoveSlots(bar);

	DEFAULT_CHAT_FRAME:AddMessage( "FarmIt:  "..bar.." Orientation = "..FI_Config["Orientation"][bar] );
end

function FI_MoveSlots( bar )
	-- determine orientation
	if (FI_Config["Orientation"][bar] == "VERTICAL") then
		point = "BOTTOM";
		relative = "TOP";
		x = 0;
		y = FI_Pad;
	elseif (FI_Config["Orientation"][bar] == "HORIZONTAL") then
		if (FI_Config["Align"][bar] == "RIGHT") then
			point = "LEFT";
			relative = "RIGHT";
			x = FI_Pad;
			y = 0;
		else
			point = "RIGHT";
			relative = "LEFT";
			x = -FI_Pad;
			y = 0;
		end
	end
	
	for s=1,FI_MaxSlots do
		local slot = bar.."_S"..s;

		-- dynamic anchoring
		if (s > 1) then
			local prev = "_S"..s-1;
			anchor = bar..prev;
		else
			anchor = bar;
		end
		
		-- set position
		getglobal(slot):ClearAllPoints();
		getglobal(slot):SetPoint(point, anchor, relative, x,y);
	end
end

--------------------------------------------------------------------------------
--  ITEM TEXT
--------------------------------------------------------------------------------
function FI_ToggleText( bar )
	-- flip the setting
	if (FI_Config["Text"][bar]) then
		FI_Config["Text"][bar] = false;
	else
		FI_Config["Text"][bar] = true;
	end

	-- apply the change
	if (FI_Config["Orientation"][bar] == "VERTICAL") then
		FI_TextVis(bar);
	end
	
	DEFAULT_CHAT_FRAME:AddMessage( "FarmIt:  Text["..bar.."] = "..FI_Boolean(FI_Config["Text"][bar]) );
end

function FI_TextVis( bar )
	for s=1,FI_MaxSlots do
		local slot = bar.."_S"..s;
		if (FI_Config["Text"][bar]) then
			getglobal(slot.."_Text"):Show();
		else
			getglobal(slot.."_Text"):Hide();
		end
	end
end

function FI_TextAlign( slot, align )
	local anchor = slot.."_Icon";
	local y=0;
	
	if (align == "LEFT") then
		point = "RIGHT";
		x = "-10";
	else
		point = "LEFT";
		x = "10";
	end
	
	getglobal(slot.."_Text"):ClearAllPoints();
	getglobal(slot.."_Text"):SetPoint(point, anchor, align, x,y);
end

--------------------------------------------------------------------------------
--  STATISTICS
--------------------------------------------------------------------------------
function FI_Track( itemID )
	-- coming in future version
end

--------------------------------------------------------------------------------
--  SLASH COMMANDS
--------------------------------------------------------------------------------
function FI_Command( cmd )
	if (cmd == "") then
		DEFAULT_CHAT_FRAME:AddMessage( 
			"FarmIt:  Available commands...\n"..
			"    /farmit help\n"..
			"        Show the help window.\n"..
			"    /farmit show\n"..
			"        Toggle visibility of the entire mod.    [ hide | show ]\n"..
			"    /farmit notify\n"..
			"        Toggle notification of item objective success.    [ off | on ]\n"..
			"    /farmit reset\n"..
			"        Reset the mod to default settings."
		);
	
	elseif (cmd == "help") then
		FI_Help:Show();

	elseif (cmd == "show") then
		FI_ToggleVis("FI");
		DEFAULT_CHAT_FRAME:AddMessage( 
			"FarmIt:  Show Mod = "..FI_Boolean(FI_Config["Display"]["FI"])
		);

	elseif (cmd == "notify") then
		FI_Config["Notify"] = FI_Toggle(FI_Config["Notify"]);
		DEFAULT_CHAT_FRAME:AddMessage( 
			"FarmIt:  Objective Notification = "..FI_Boolean(FI_Config["Notify"])
		);

	elseif (cmd == "reset") then
		FI_Reset();

	end
end

--------------------------------------------------------------------------------
--  HELP TEXT
--------------------------------------------------------------------------------
function FI_HelpText()
	getglobal("FI_Help_Title"):SetText("FarmIt v"..FI_Version);
	getglobal("FI_Help_Subtitle"):SetText("By CHiLLZ");

	getglobal("FI_Help_Heading1"):SetText("[ Bar ]");
	getglobal("FI_Help_Text1"):SetText(
		"The base of the item bar allows you to control the bar configuration settings.\n"..
		"\n"..
		"Click and drag to move the bar.\n"..
		"\n"..
		"Right-click to toggle item text.    [ off | on ]\n"..
		"\n"..
		"Shift-click to change bar/text alignment.    [ left | right ]\n"..
		"\n"..
		"Ctrl-click to change bar orientation.    [ vertical | horizontal ]\n"..
		"\n"..
		"Click the plus (+) button to increase the number of item slots on the bar.\n"..
		"\n"..
		"Click the minus (-) button to decrease the number of item slots on the bar.\n"
	);

	getglobal("FI_Help_Heading2"):SetText("[ Item Slots ]");
	getglobal("FI_Help_Text2"):SetText(
		"Place any item from your inventory into one of the bar slots\n"..
		"to keep track of how many you have.\n"..
		"\n"..
		"Click a slot to select its contents and move them to another slot.\n"..
		"\n"..
		"Right-click a slot to clear it.\n"..
		"\n"..
		"Shift-click the slot to include your bank inventory in the item count. (per slot)\n"..
		"You do *not* need to be at the bank for this to work! Item counts turn\n"..
		"yellow when 'include bank' is enabled.\n"..
		"\n"..
		"Ctrl-click a slot to set an item quantity objective, similar to quest tracking.\n"..
		"Item objectives will turn green when they have been met.\n"
	);
end
